@@ -4,6 +4,6 @@
 __author__ = "Timo Röhling <timo.roehling@fkie.fraunhofer.de>"
 __copyright__ = "Copyright (c) 2013,2014 Fraunhofer FKIE"
 __license__ = "BSD"
-__version__ = "1.2.6"
-__all__ = [ "cmake", "diagnostics", "linter", "main", "output", "util" ]
+__version__ = "1.3.5"
+__all__ = [ "cmake", "diagnostics", "linter", "main", "output", "packages", "util" ]
 
