@@ -37,12 +37,13 @@ def includes(linter):
         info.build_includes = set([])
     def on_include_directories(info, cmd, args):
         _, args = cmake_argparse(args, { "AFTER" : "-", "BEFORE" : "-", "SYSTEM" : "-" })
-        info.build_includes |= set([ info.package_path(d) for d in args])
+        includes = set([ info.package_path(d) for d in args])
+        info.build_includes |= includes
     def on_final(info):
         for incl in info.build_includes:
             if os.path.isabs(incl) or not incl: continue
             if not os.path.isdir(info.real_path(incl)):
-                info.report (ERROR, "MISSING_BUILD_INCLUDE_PATH", path="%s" % incl)
+                info.report (ERROR, "MISSING_BUILD_INCLUDE_PATH", path=incl)
 
     linter.add_init_hook(on_init)
     linter.add_command_hook("include_directories", on_include_directories)
@@ -106,7 +107,7 @@ def source_files(linter):
             if not source_file: continue
             source_file = info.package_path(source_file)
             if os.path.isabs(source_file): continue
-            if not os.path.isfile(os.path.join(info.path, source_file)):
+            if not os.path.isfile(info.real_path(source_file)):
                 info.report(ERROR, "MISSING_FILE", cmd=cmd, file=source_file)
 
     linter.add_command_hook("add_executable", on_add_executable)
@@ -128,6 +129,7 @@ def depends(linter):
     def on_init(info):
         info.required_packages = set([])
         info.catkin_components = set([])
+        info.checked_packages = set([])
     def on_find_package(info, cmd, args):
         opts, args = cmake_argparse(args, { "REQUIRED": "-", "COMPONENTS": "*" })
         if not "project" in info.commands:
@@ -140,18 +142,29 @@ def depends(linter):
             info.report(ERROR, "ORDER_VIOLATION", first_cmd="catkin_package", second_cmd=cmd)
         if not opts["REQUIRED"]:
             info.report(WARNING, "MISSING_REQUIRED", pkg="catkin")
+            info.required_packages.add("catkin")
         for pkg in opts["COMPONENTS"]:
             if pkg in info.find_packages:
                 info.report(ERROR, "DUPLICATE_FIND", pkg=pkg)
             if not info.env.is_catkin_pkg(pkg):
                 info.report(ERROR, "NO_CATKIN_COMPONENT", pkg=pkg)
+        for pkg in args[1:]:
+            if info.env.is_known_pkg(pkg):
+                info.report(ERROR, "MISSING_COMPONENTS", pkg=pkg)
         info.find_packages |= set(opts["COMPONENTS"])
         info.required_packages |= set(opts["COMPONENTS"])
         info.catkin_components |= set(opts["COMPONENTS"])
+    def on_if(info, cmd, args):
+        for arg in args:
+            if arg.endswith("_FOUND"):
+                info.checked_packages.add(arg[0:-6])
     def on_final(info):
         for pkg in info.required_packages - info.build_dep - info.buildtool_dep:
             if info.env.is_known_pkg(pkg):
                 info.report(ERROR, "MISSING_DEPEND", pkg=pkg, type="build")
+        for pkg in info.find_packages - info.required_packages - info.checked_packages:
+            if info.env.is_catkin_pkg(pkg):
+                info.report(ERROR, "MISSING_REQUIRED", pkg=pkg)
         for pkg in info.build_dep - info.find_packages:
             if info.env.is_catkin_pkg(pkg):
                 info.report(ERROR, "UNCONFIGURED_BUILD_DEPEND", pkg=pkg)
@@ -159,6 +172,7 @@ def depends(linter):
     linter.require(manifest_depends)
     linter.add_init_hook(on_init)
     linter.add_command_hook("find_package", on_find_package)
+    linter.add_command_hook("if", on_if)
     linter.add_final_hook(on_final)
 
 
@@ -176,6 +190,8 @@ def exports(linter):
         for pkg in opts["DEPENDS"]:
             if info.env.is_catkin_pkg(pkg):
                 info.report(ERROR, "CATKIN_AS_SYSTEM_DEPEND", pkg=pkg)
+            elif pkg in info.pkg_modules:
+                info.report(ERROR, "EXPORTED_PKG_CONFIG", pkg=pkg)
             elif not pkg in info.find_packages and not ("%s_INCLUDE_DIRS" % pkg in info.var and "%s_LIBRARIES" % pkg in info.var):
                 info.report(ERROR, "UNCONFIGURED_SYSTEM_DEPEND", pkg=pkg)
         includes = [ info.package_path(d) for d in opts["INCLUDE_DIRS"] ]
@@ -194,9 +210,18 @@ def exports(linter):
                 info.report (WARNING, "SUGGEST_CATKIN_DEPEND", pkg=pkg)
         if info.export_includes and info.libraries and not info.export_libs:
             info.report(WARNING, "MISSING_EXPORT_LIB")
+        if info.executables or info.libraries:
+            for incl in info.export_includes - info.build_includes:
+                info.report (WARNING, "MISSING_BUILD_INCLUDE", path=incl)
         for incl in info.export_includes:
             if not os.path.isdir(info.real_path(incl)):
                 info.report (ERROR, "MISSING_EXPORT_INCLUDE_PATH", path=incl)
+        includes = info.build_includes | info.export_includes
+        for d1 in includes:
+            if not os.path.isabs(d1):
+                for d2 in includes:
+                    if d1.startswith("%s%s" % (d2, os.path.sep)):
+                        info.report(WARNING, "AMBIGUOUS_BUILD_INCLUDE", path=d1, parent_path=d2)
         for lib in info.export_libs:
             if not lib in info.targets: continue
             if info.target_outputs[lib] != lib:
@@ -205,6 +230,8 @@ def exports(linter):
                 info.report(ERROR, "EXPORT_LIB_NOT_LIB", target=lib)
 
     linter.require(manifest_depends)
+    linter.require(pkg_config)
+    linter.require(includes)
     linter.require(targets)
     linter.add_init_hook(on_init)
     linter.add_command_hook("catkin_package", on_catkin_package)
@@ -220,7 +247,7 @@ def name_check(linter):
             tgl = target.lower()
             tnc = True
             for nf in name_fragments:
-                if len(nf) < 3: continue
+                if len(nf) < 2: continue
                 if nf in tgl:
                     tnc = False
                     break
@@ -234,6 +261,16 @@ def name_check(linter):
     linter.add_final_hook(on_final)
 
 
+def pkg_config(linter):
+    def on_init(info):
+        info.pkg_modules = set([])
+    def on_pkg_check_modules(info, cmd, args):
+        info.pkg_modules.add(args[0])
+
+    linter.add_init_hook(on_init)
+    linter.add_command_hook("pkg_check_modules", on_pkg_check_modules)
+
+
 def installs(linter):
     def on_init(info):
         info.install_targets = set([])
@@ -248,7 +285,7 @@ def installs(linter):
             install_type = "DIRECTORY"
         if opts["FILES"]:
             install_type = "FILES"
-            info.install_files |= set([os.path.normpath(os.path.join(opts["DESTINATION"], info.package_path(f))) for f in opts["FILES"] ])
+            info.install_files |= set([os.path.normpath(os.path.join(opts["DESTINATION"], os.path.basename(f))) for f in opts["FILES"] ])
         if opts["TARGETS"]:
             install_type = "TARGETS"
             info.install_targets |= set(opts["TARGETS"])
@@ -264,11 +301,8 @@ def installs(linter):
             if not lib in info.install_targets:
                 info.report(ERROR if "install" in info.commands else NOTICE, "UNINSTALLED_EXPORT_LIB", target=lib)
         for tgt in info.executables - info.install_targets:
-            if "test" in tgt.lower(): continue
+            if "test" in tgt.lower() or "example" in tgt.lower(): continue
             info.report(WARNING if "install" in info.commands else NOTICE, "MISSING_INSTALL_TARGET", target=tgt)
-        if info.executables or info.libraries:
-            for incl in info.export_includes - info.build_includes:
-                info.report (WARNING, "MISSING_BUILD_INCLUDE", path="%s" % incl[12:])
         if info.export_includes and not info.install_includes:
             info.report (ERROR if "install" in info.commands else NOTICE, "MISSING_INSTALL_INCLUDE")
         for target, depends in iteritems(info.target_links):
@@ -295,7 +329,7 @@ def plugins(linter):
                 if not plugin.startswith("${prefix}/"):
                     info.report (ERROR, "PLUGIN_EXPORT_PREFIX", export=export.tagname)
                 else:
-                    if not os.path.isfile(os.path.join(info.path, plugin[10:])):
+                    if not os.path.isfile(info.real_path(plugin[10:])):
                         info.report (ERROR, "PLUGIN_MISSING_FILE", export=export.tagname, file=plugin)
                     if not os.path.normpath("/catkin-target/share/%s/%s" % (info.manifest.name, plugin[10:])) in info.install_files:
                         info.report (ERROR if "install" in info.commands else NOTICE, "PLUGIN_MISSING_INSTALL", export=export.tagname, file=plugin[10:])
@@ -370,6 +404,7 @@ def all(linter):
     linter.require(depends)
     linter.require(exports)
     linter.require(name_check)
+    linter.require(pkg_config)
     linter.require(installs)
     linter.require(plugins)
     linter.require(message_generation)
