@@ -79,10 +79,31 @@ This construct was intended to facilitate the migration from
 Rosbuild to Catkin. It is deprecated and should not be used any more.
 """
 ),
+"DEPRECATED_CMD" : ( "%(old_cmd)s() is deprecated, use %(new_cmd)s() instead",
+"""\
+Some macros have been deprecated and replaced by newer versions.
+Please upgrade your CMakeLists.txt to ensure compatibility with
+future caktin versions.
+"""
+),
+"MISSING_CMAKE_MODULES" : ( "find_package(%(pkg)s) before find_package(cmake_modules)",
+"""\
+You need to find_package() cmake_modules before you can use
+one of its custom configuration modules.
+"""
+),
 "MISSING_REQUIRED" : ( "find_package(%(pkg)s) has no REQUIRED option",
 """\
 The package cannot build without this dependency, so it should be
-marked as REQUIRED accordingly.
+marked as REQUIRED accordingly. Use if(%(pkg)s_FOUND) clauses to use
+optional packages.
+"""
+),
+"MISSING_COMPONENTS" : ("missing COMPONENTS keyword before '%(pkg)s'",
+"""\
+The find_package(catkin) call can add other catkin packages as
+dependencies with the COMPONENTS keyword. The find_package() command
+lists additional packages but has no COMPONENTS keyword.
 """
 ),
 "NO_CATKIN_COMPONENT" : ("'%(pkg)s' in find_package(catkin) is not a catkin package",
@@ -229,6 +250,13 @@ catkin_package() command, but that path is not mentioned in any
 include_directories() call.
 """
 ),
+"AMBIGUOUS_BUILD_INCLUDE" : ("include paths '%(path)s' and '%(parent_path)s' are ambiguous",
+"""\
+You have used two include paths where one is a parent of
+the other. Thus the same headers can be included with two different include paths
+which may confuse users. It is recommended that you keep your include paths consistent.
+"""
+),
 "MISSING_EXPORT_INCLUDE_PATH" : ("exported include path '%(path)s' does not exist",
 """\
 You have listed an invalid include path in the INCLUDE_DIRS stanza of the
@@ -340,7 +368,7 @@ characters in its name. You probably forget to call set_target_properties(... PR
 OUTPUT_NAME ...)
 """
 ),
-"TARGET_NAME_COLLISION" : ("target '%(target)s' should contain package name",
+"TARGET_NAME_COLLISION" : ("target name '%(target)s' might not be sufficiently unique",
 """\
 The CMake build system requires all target identifiers to be globally unique.
 For this reason, it is highly recommended that you add the package name as in
@@ -464,15 +492,48 @@ adds subdir B, which adds subdir A again.
 "SUBPROJECT" : ( "subdirectory '%(subdir)s' contains a subproject",
 """\
 Your package has an independent subproject. This can interact
-with catkin in unusual ways and is strongly discouraged.
+with catkin in unusual ways and is strongly discouraged. No
+further checks are performed in this subdirectory.
 """
 ),
+"GLOBAL_VAR_COLLISION" : ( "global variable '%(var)s' should contain project name",
+"""\
+Global variables and options are stored in the cache.
+You should prefix your variable names with the project name to
+avoid name collisions with other packages.
+"""
+),
+"ENV_VAR" : ( "environment variables should not be used",
+"""\
+The behavior of your build should not depend on any
+environment variables.
+"""
+),
+"EXPORTED_PKG_CONFIG" : ( "catkin_package() exports pkg-config module '%(pkg)s'",
+"""\
+Although CMake can invoke pkg-config to detect other modules,
+this does not work well with catkin, as pkg-config may require
+you to add link directories. Use the results of pkg_check_module()
+as hint for find_path() and find_library() instead.
+"""),
 "OS_ERROR" : ( "OS error: %(msg)s",
 """\
 An operating system error has occured. This is not a linting problem per se but
 might be caused by a missing or unreadable file.
 """
 ),
+"ENDBLOCK_ARGS" : ("extra arguments in %(cmd)s()",
+"""\
+The catkin manual recommends that %(cmd)s and other end-of-block statements
+have no arguments. If you have nested blocks, you should indent them
+properly instead.
+"""
+),
+"CMD_CASE" : ("%(cmd)s() should be all lower-case",
+"""\
+The catkin manual recommends that all commands be written in lower case.
+"""
+),
 }
 
 def msg(msg_id, **kwargs):
